AliasTerm

Type Alias AliasTerm 

pub type AliasTerm<'db> = AliasTerm<DbInterner<'db>>;

Aliased Type

pub struct AliasTerm<'db> {
    pub args: GenericArgs<'db>,
    pub kind: AliasTermKind<DbInterner<'db>>,
    /* private fields */
}

Fields

args: GenericArgs<'db>

The parameters of the associated or opaque item.

For a projection, these are the generic parameters for the trait and the GAT parameters, if there are any.

For an inherent projection, they consist of the self type and the GAT parameters, if there are any.

For RPIT the generic parameters are for the generics of the function, while for TAIT it is used for the generic parameters of the alias.

kind: AliasTermKind<DbInterner<'db>>