fn stable_cmp_existential_predicate<'db>(
a: &ExistentialPredicate<'db>,
b: &ExistentialPredicate<'db>,
) -> OrderingExpand description
Compares via an ordering that will not change if modules are reordered or other changes are made to the tree. In particular, this ordering is preserved across incremental compilations.